@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2016   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -320,13 +320,13 @@ void set_tfmcc_ack_info(struct group_list_t *group,
                         struct tfmcc_ack_info_he *tfmcc)
 {
     struct timeval now, send_time;
-    unsigned ccrate;
+    int64_t ccrate;
 
     tfmcc->exttype = EXT_TFMCC_ACK_INFO;
     tfmcc->extlen = sizeof(struct tfmcc_ack_info_he) / 4;
     tfmcc->cc_seq = htons(group->ccseq);
     ccrate = current_cc_rate(group);
-    glog4(group, "ccrate=%d", ccrate);
+    glog4(group, "ccrate=" F_i64, ccrate);
     tfmcc->cc_rate = htons(quantize_rate(ccrate));
     //tfmcc->cc_rate = htons(quantize_rate(current_cc_rate(group)));
     tfmcc->flags = 0;
@@ -630,7 +630,7 @@ void init_tfmcc_fb_round(struct group_list_t *group, uint16_t new_ccseq)
 void handle_tfmcc_data_info(struct group_list_t *group,
                             const struct tfmcc_data_info_he *tfmcc)
 {
-    uint32_t ccrate;
+    int64_t ccrate;
     uint16_t new_ccseq;
 
     new_ccseq = ntohs(tfmcc->cc_seq);
@@ -1033,7 +1033,7 @@ void handle_cong_ctrl(struct group_list_t *group, const unsigned char *message,
     const struct cong_ctrl_h *cong_ctrl;
     const struct cc_item *cc_list;
     int listlen, i, ccidx, clridx;
-    uint32_t ccrate;
+    int64_t ccrate;
     uint16_t new_ccseq;
     double new_rtt;
 
