@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2015   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2018   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -795,7 +795,7 @@ void send_hb_response(const union sockaddr_u *src, int response)
 }
 
 /**
- * Sends a PROXY_KEY message to the first listed public multicast address.
+ * Sends a PROXY_KEY message to each public multicast address.
  */
 void send_proxy_key()
 {
@@ -806,7 +806,7 @@ void send_proxy_key()
     unsigned int meslen, siglen;
     uint16_t bloblen, dhlen;
     char pubname[INET6_ADDRSTRLEN];
-    int rval;
+    int rval, i;
 
     packet = safe_calloc(sizeof(struct uftp_h) + sizeof(struct hb_req_h) +
                     (PUBKEY_LEN * 3) , 1);
@@ -866,17 +866,19 @@ void send_proxy_key()
     proxykey->hlen = (sizeof(struct proxy_key_h) + bloblen + dhlen + siglen)/4;
 
     meslen = sizeof(struct uftp_h) + (proxykey->hlen * 4);
-    if (nb_sendto(listener, packet, meslen, 0, 
-                  (struct sockaddr *)&pub_multi[0],
-                  family_len(pub_multi[0])) == SOCKET_ERROR) {
-        sockerror(0, 0, 0, "Error sending PROXY_KEY");
-    } else {
-        if ((rval = getnameinfo((struct sockaddr *)&pub_multi[0],
-                family_len(pub_multi[0]), pubname, sizeof(pubname), NULL, 0,
-                NI_NUMERICHOST)) != 0) {
-            log1(0, 0, 0, "getnameinfo failed: %s", gai_strerror(rval));
+    for (i = 0; i < pub_multi_count; i++) {
+        if (nb_sendto(listener, packet, meslen, 0, 
+                      (struct sockaddr *)&pub_multi[i],
+                      family_len(pub_multi[i])) == SOCKET_ERROR) {
+            sockerror(0, 0, 0, "Error sending PROXY_KEY");
+        } else {
+            if ((rval = getnameinfo((struct sockaddr *)&pub_multi[i],
+                    family_len(pub_multi[i]), pubname, sizeof(pubname), NULL, 0,
+                    NI_NUMERICHOST)) != 0) {
+                log1(0, 0, 0, "getnameinfo failed: %s", gai_strerror(rval));
+            }
+            log2(0, 0, 0, "Sent PROXY_KEY to %s", pubname);
         }
-        log2(0, 0, 0, "Sent PROXY_KEY to %s", pubname);
     }
     free(packet);
 }
