@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2015   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2020   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -309,7 +309,7 @@ int send_keyinfo(const struct finfo_t *finfo, int attempt)
                 free(iv);
                 return 0;
             }
-            if (packet_wait) usleep(packet_wait);
+            if (packet_wait) usleep(packet_wait/1000);
             memset(keylist, 0, maxdest * sizeof(struct destkey));
             iv_init = 0;
             dests = 0;
@@ -353,11 +353,7 @@ int send_fileinfo(const struct finfo_t *finfo, int attempt)
     fileinfo->namelen = (uint8_t)(0 + ceil(strlen(finfo->destfname) / 4.0));
     fileinfo->lofsize = htonl((finfo->size & 0xFFFFFFFF));
     fileinfo->hifsize = htons((uint16_t)(finfo->size >> 32));
-    if (sync_mode) {
-        fileinfo->ftstamp = htonl(finfo->tstamp);
-    } else {
-        fileinfo->ftstamp = 0;
-    }
+    fileinfo->ftstamp = htonl(finfo->tstamp);
     gettimeofday(&tv, NULL);
     fileinfo->tstamp_sec = htonl(tv.tv_sec);
     fileinfo->tstamp_usec = htonl(tv.tv_usec);
