@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2020   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -209,8 +209,8 @@ int announce_phase(struct finfo_t *finfo)
         glog2(finfo, "  sending as: %s", finfo->destfname);
         switch (finfo->ftype) {
         case FTYPE_REG:
-            glog2(finfo, "Bytes: %s  Blocks: %d  Sections: %d", 
-                        printll(finfo->size), finfo->blocks, finfo->sections);
+            glog2(finfo, "Bytes: " F_i64 "  Blocks: %d  Sections: %d", 
+                        finfo->size, finfo->blocks, finfo->sections);
             glog3(finfo, "small section size: %d, "
                 "big section size: %d, " "# big sections: %d",
                 finfo->secsize_small, finfo->secsize_big, finfo->big_sections);
@@ -435,7 +435,8 @@ void handle_transfer_phase(unsigned char *packet,unsigned char *decrypted,
         meslen = decryptlen;
     } else {
         if ((keytype != KEY_NONE) && ( (header->func == STATUS) ||
-                (header->func == COMPLETE) || (header->func == ABORT))) {
+                (header->func == COMPLETE) || (header->func == ABORT) ||
+                (header->func == CC_ACK))) {
             glog1(finfo, "Rejecting %s message from %08X: not encrypted",
                          func_name(header->func), ntohl(header->src_id));
             return;
@@ -493,8 +494,8 @@ int seek_block(const struct finfo_t *finfo, int file, int block,
         return 0;
     }
     if (new_offset != (f_offset_t)block * blocksize) {
-        glog0(finfo, "block %d: offset is %s", block, printll(new_offset));
-        glog0(finfo, "  should be %s", printll((f_offset_t)block * blocksize));
+        glog0(finfo, "block %d: offset is " F_i64, block, new_offset);
+        glog0(finfo, "  should be " F_i64, (f_offset_t)block * blocksize);
         if ((new_offset = lseek_func(file, ((f_offset_t)block * blocksize),
                                      SEEK_SET)) == -1) {
             gsyserror(finfo, "lseek failed for file");
@@ -531,11 +532,12 @@ static int max_time_timeout, max_passes_exceeded;
 int rate_change;
 uint32_t current_position;
 uint16_t cc_seq;
-uint32_t cc_rate;
+int64_t cc_rate;
 double adv_grtt;
 
 // TODO: not shared between threads, move?
-int slowstart, clr, clr_drop, new_rate;
+int slowstart, clr, clr_drop;
+int64_t new_rate;
 struct timeval last_clr_time;
 
 static int file;
@@ -594,10 +596,10 @@ THREAD_FUNC transfer_send_thread(void *infop)
     int numbytes, attempt, l_file_done_flag, current_nak, cc_len, done_sent;
     double l_adv_grtt;
     uint16_t l_cc_seq, pass, section, last_section;
-    uint32_t l_cc_rate, block;
-    int l_packet_wait, l_rate_change, max_time;
+    uint32_t block;
+    int l_rate_change, max_time;
     struct timeval last_sent, current_sent, now, start_time;
-    int64_t overage, tdiff;
+    int64_t l_cc_rate, l_packet_wait, overage, tdiff;
     f_offset_t offset, curr_offset;
     struct finfo_t *finfo;
 
@@ -662,7 +664,7 @@ THREAD_FUNC transfer_send_thread(void *infop)
     do {
         if (block < finfo->blocks) {
             if (current_nak) {
-                glog5(finfo, "Sending %d, wait=%d", block, l_packet_wait);
+                glog5(finfo, "Sending %d, wait=" F_i64, block, l_packet_wait);
                 attempt = 1;
                 // TODO: try to avoid seek on consecutive packets?
                 curr_offset = offset;
@@ -680,16 +682,16 @@ THREAD_FUNC transfer_send_thread(void *infop)
                 // long we expected to sleep.  If we went over, subtract the
                 // time over from the next sleep time.  This way we maintain
                 // the proper average sleep time.
-                if (l_packet_wait > overage) {
-                    usleep(l_packet_wait - (int32_t)overage);
+                if (l_packet_wait - overage >= 1000) {
+                    usleep((l_packet_wait - overage) / 1000);
                 }
                 gettimeofday(&current_sent, NULL);
-                tdiff = diff_usec(current_sent, last_sent);
+                tdiff = diff_usec(current_sent, last_sent) * 1000;
                 if (l_packet_wait) overage += tdiff - l_packet_wait;
                 last_sent = current_sent;
                 if (log_level >= 5) {
-                    cglog5(finfo, "tdiff=%s, ", printll(tdiff));
-                    slog5("overage=%s", printll(overage));
+                    cglog5(finfo, "tdiff=" F_i64 ", ", tdiff);
+                    slog5("overage=" F_i64, overage);
                 }
                 // When rate changes significantly, clear the overage counter
                 if (l_rate_change) {
@@ -737,7 +739,7 @@ THREAD_FUNC transfer_send_thread(void *infop)
                 gettimeofday(&last_sent, NULL);
                 done_sent = 1;
             }
-            usleep(l_packet_wait);
+            usleep(l_packet_wait / 1000);
             overage = 0;
         }
 
@@ -915,16 +917,16 @@ void transfer_receive_thread(struct finfo_t *finfo)
             rate /= 2;
             if ((min_rate > 0) && (rate < min_rate)) {
                 slowstart = 1;
-                if (min_rate > (int)(datapacketsize / grtt)) {
+                if (min_rate > (int64_t)(datapacketsize / grtt)) {
                     rate = min_rate;
                 } else {
-                    rate = (int)(datapacketsize / grtt);
+                    rate = (int64_t)(datapacketsize / grtt);
                 }
-            } else if (rate < (int)(datapacketsize / grtt)) {
+            } else if (rate < (int64_t)(datapacketsize / grtt)) {
                 slowstart = 1;
-                rate = (int)(datapacketsize / grtt);
+                rate = (int64_t)(datapacketsize / grtt);
             }
-            packet_wait = (int32_t)(1000000.0 * datapacketsize / rate);
+            packet_wait = (int64_t)(1000000000.0 * datapacketsize / rate);
             rate_change = 1;
             last_clr = diff_usec(now, last_clr_time);
             if ((last_clr > 1000000 * 2 * robust * l_adv_grtt) &&
@@ -942,7 +944,7 @@ void transfer_receive_thread(struct finfo_t *finfo)
                 if (new_rate) {
                     rate = new_rate;
                 }
-                packet_wait = (int32_t)(1000000.0 * datapacketsize / rate);
+                packet_wait = (int64_t)(1000000000.0 * datapacketsize / rate);
                 rate_change = 1;
             }
             recalculate_grtt(finfo, 1, 1);
@@ -954,22 +956,22 @@ void transfer_receive_thread(struct finfo_t *finfo)
             glog5(finfo, "adv_grtt=%.3f", l_adv_grtt);
             if ((min_rate > 0) && (rate < min_rate)) {
                 slowstart = 1;
-                if (min_rate > (int)(datapacketsize / grtt)) {
+                if (min_rate > (int64_t)(datapacketsize / grtt)) {
                     rate = min_rate;
                 } else {
-                    rate = (int)(datapacketsize / grtt);
+                    rate = (int64_t)(datapacketsize / grtt);
                 }
-                packet_wait = (int32_t)(1000000.0 * datapacketsize / rate);
+                packet_wait = (int64_t)(1000000000.0 * datapacketsize / rate);
                 rate_change = 1;
-            } else if (rate < (int)(datapacketsize / grtt)) {
+            } else if (rate < (int64_t)(datapacketsize / grtt)) {
                 slowstart = 1;
-                rate = (int)(datapacketsize / grtt);
-                packet_wait = (int32_t)(1000000.0 * datapacketsize / rate);
+                rate = (int64_t)(datapacketsize / grtt);
+                packet_wait = (int64_t)(1000000000.0 * datapacketsize / rate);
                 rate_change = 1;
             }
             gettimeofday(&fb_end, NULL);
             add_timeval_d(&fb_end, 6 * l_adv_grtt);
-            cc_rate = 0xFFFFFFFF;
+            cc_rate = 0xFFFFFFFFFFFF;
             cc_seq++;
             glog4(finfo, "Starting feedback round %d", cc_seq);
         }
@@ -1004,6 +1006,11 @@ void transfer_receive_thread(struct finfo_t *finfo)
             timeout.tv_usec = 0;
             add_timeval_d(&timeout, 1 * l_adv_grtt);
         }
+        // Don't wait longer than 1 second
+        if (timeout.tv_sec >= 1) {
+            timeout.tv_sec = 1;
+            timeout.tv_usec = 0;
+        }
 
         if ((rcv_status = read_packet(sock, &receiver, packet, &len,
                                       MAXMTU, &timeout, &tos)) == -1) {
@@ -1147,20 +1154,20 @@ int transfer_phase(struct finfo_t *finfo)
             rate = init_rate;
         } else {
             // Initialize rate to 1 packet per GRTT
-            rate = (int32_t)(((double)datapacketsize / grtt));
+            rate = (int64_t)(((double)datapacketsize / grtt));
         }
-        packet_wait = (int32_t)(1000000.0 * datapacketsize / rate);
+        packet_wait = (int64_t)(1000000000.0 * datapacketsize / rate);
         adv_grtt = (double)datapacketsize / rate;
         if (adv_grtt < grtt) {
             adv_grtt = grtt;
         }
         cc_seq = 0;
-        cc_rate = 0xFFFFFFFF;
+        cc_rate = 0xFFFFFFFFFFFF;
         slowstart = 1;
         // Pick an initial CLR based on who has the highest RTT
-        for (tmp_rtt = 9999, clr = -1, i = 0; i < destcount; i++) {
+        for (tmp_rtt = 0, clr = -1, i = 0; i < destcount; i++) {
             if (!client_error(i) && (!destlist[i].isproxy) &&
-                    (destlist[i].rtt < tmp_rtt)) {
+                    (destlist[i].rtt > tmp_rtt)) {
                 clr = i;
                 tmp_rtt = destlist[i].rtt;
             }
