@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2015   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -501,10 +501,10 @@ int send_files(void)
             log2(group_info.group_id, 0, 0,
                     "Transfer rate: full interface speed");
         } else {
-            log2(group_info.group_id, 0, 0, "Transfer rate: %d Kbps (%d KB/s)",
+            log2(group_info.group_id, 0, 0, "Transfer rate: " F_i64 " Kbps (" F_i64 " KB/s)",
                        rate * 8 / 1024, rate / 1024);
             log2(group_info.group_id, 0, 0,
-                    "Wait between packets: %d us", packet_wait);
+                    "Wait between packets: " F_i64 " ns", packet_wait);
         }
     } else if (cc_type == CC_TFMCC) {
         log2(group_info.group_id, 0, 0, "Transfer rate: dynamic via TFMCC");
