@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2020   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -50,14 +50,16 @@
 #define rmdir(dir) _rmdir(dir)
 #define getpid() _getpid()
 #define mkdir(dir, mode) _mkdir(dir)
-#define usleep(t) Sleep((t)/1000)
-#define sleep(t) Sleep((t)*1000)
+#define usleep(t) Sleep((int)(t)/1000)
+#define sleep(t) Sleep((int)(t)*1000)
 #define strdup(p) _strdup(p)
 #define utime(f, t) _utime(f, t)
 #define isfullpath(str) (((str[1] == ':') && (str[2] == '\\')) || \
                          ((str[0] == '\\') && (str[1] == '\\')))
 #define PATH_SEP '\\'
 
+#define F_i64 "%I64d"
+
 typedef uint64_t f_offset_t;
 typedef struct _stat32i64 stat_struct;
 typedef struct _utimbuf utim_buf;
@@ -108,6 +110,8 @@ typedef unsigned int socklen_t;
 #define PATH_SEP '/'
 #endif
 
+#define F_i64 "%lld"
+
 typedef uint64_t f_offset_t;
 typedef struct stat stat_struct;
 typedef struct utimbuf utim_buf;
@@ -141,7 +145,7 @@ typedef pthread_t thread_t;
 
 #endif // if WINDOWS
 
-#define VERSIONSTR "UFTP version 4.9.9  Copyright (C) 2001-2019  Dennis A. Bush"
+#define VERSIONSTR "UFTP version 4.10.1  Copyright (C) 2001-2020  Dennis A. Bush"
 #define UFTP_VER_NUM 0x40
 
 #define ANNOUNCE      1
@@ -280,7 +284,7 @@ typedef pthread_t thread_t;
 #define DESTNAME_LEN 80
 #define IFNAME_LEN 25
 #define PORTNAME_LEN 20
-#define MAX_INTERFACES 100
+#define MAX_INTERFACES 200
 #define MAXMTU 9000
 
 #define PUBKEY_LEN 264  // big enough for a keyblob with RSA-2048
