@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2016   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2019   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -134,11 +134,10 @@ void getiflist(struct iflist *list, int *len)
         if ((ifidx = if_nametoindex(ifa_tmp->ifa_name)) == 0) {
             syserror(0, 0, 0, "Error getting interface index for interface %s",
                               ifa_tmp->ifa_name);
-            continue;
-        }
-        if (ifa_tmp->ifa_addr && ((ifa_tmp->ifa_addr->sa_family == AF_INET) ||
-                                  (ifa_tmp->ifa_addr->sa_family == AF_INET6)) &&
-                    ((ifa_tmp->ifa_flags & IFF_UP) != 0)) {
+        } else if (ifa_tmp->ifa_addr && 
+                   ((ifa_tmp->ifa_addr->sa_family == AF_INET) ||
+                    (ifa_tmp->ifa_addr->sa_family == AF_INET6)) &&
+                   ((ifa_tmp->ifa_flags & IFF_UP) != 0)) {
             memset(&list[*len], 0, sizeof(struct iflist));
             strncpy(list[*len].name, ifa_tmp->ifa_name,
                     sizeof(list[*len].name) - 1);
@@ -1616,7 +1615,7 @@ int multicast_join(SOCKET s, uint32_t group_id, const union sockaddr_u *multi,
 {
     struct group_req greq;
     struct group_source_req gsreq;
-    int level, i, j;
+    int level = 0, i, j;
 
     for (i = 0; i < addrlen; i++) {
         if (!addrlist[i].ismulti) {
@@ -1668,7 +1667,7 @@ void multicast_leave(SOCKET s, uint32_t group_id, const union sockaddr_u *multi,
 {
     struct group_req greq;
     struct group_source_req gsreq;
-    int level, i, j;
+    int level = 0, i, j;
 
     for (i = 0; i < addrlen; i++) {
         if (!addrlist[i].ismulti) {
@@ -2141,13 +2140,13 @@ int unquantize_gsize(uint8_t size)
  * Convert rate from an int to a 16-bit float
  * As defined in RFC 5740
  */
-uint16_t quantize_rate(uint32_t rate)
+uint16_t quantize_rate(int64_t rate)
 {
     int E;
     double M;
     int rval;
 
-    M = rate;
+    M = (double)rate;
     E = 0;
     while (M > 10) {
         M /= 10;
@@ -2168,7 +2167,7 @@ uint16_t quantize_rate(uint32_t rate)
  * Convert rate in B/s from a 16-bit float to an int
  * As defined in RFC 5740
  */
-uint32_t unquantize_rate(uint16_t rate)
+int64_t unquantize_rate(uint16_t rate)
 {
     int E, i;
     double rval;
@@ -2179,7 +2178,6 @@ uint32_t unquantize_rate(uint16_t rate)
         rval *= 10;
     }
 
-    // For now, cap at max uint32 (~4.2GB/s)
-    return (uint32_t)(rval > 0xFFFFFFFF ? 0xFFFFFFFF : rval);
+    return (int64_t)rval;
 }
 
